@@ -115,7 +115,11 @@ get_list_from_configuration (GWeatherLocation *world,
     return list;
 }
 
-#define CONFIGURATION "[{'location': <(uint32 2, <('Rio de Janeiro', 'SBES', false, [(-0.39822596348113698, -0.73478361508961265)], [(-0.39822596348113698, -0.73478361508961265)])>)>}, {'location': <(uint32 2, <('Coordinated Universal Time (UTC)', '@UTC', false, @a(dd) [], @a(dd) [])>)>}]"
+#define CONFIGURATION "[                                                                                                                                                                 \
+                        {'location': <(uint32 2, <('Rio de Janeiro', 'SBES', false, [(-0.39822596348113698, -0.73478361508961265)], [(-0.39822596348113698, -0.73478361508961265)])>)>}, \
+                        {'location': <(uint32 2, <('Coordinated Universal Time (UTC)', '@UTC', false, @a(dd) [], @a(dd) [])>)>},                                                         \
+                        {'location': <(uint32 2, <('Perm', 'USPP', true, [(1.0122909661567112, 0.98174770424681035)], [(1.0122909661567112, 0.98174770424681035)])>)>}                   \
+                       ]"
 
 static void test_timezones (void);
 
@@ -128,12 +132,12 @@ test_named_timezones_deserialized (void)
     world = gweather_location_get_world ();
     g_assert (world);
 
-    list = get_list_from_configuration (world, CONFIGURATION, 2);
+    list = get_list_from_configuration (world, CONFIGURATION, 3);
     for (l = list; l != NULL; l = l->next)
         gweather_location_unref (l->data);
     g_list_free (list);
 
-    list = get_list_from_configuration (world, CONFIGURATION, 2);
+    list = get_list_from_configuration (world, CONFIGURATION, 3);
     for (l = list; l != NULL; l = l->next) {
         GWeatherLocation *loc = l->data;
         GWeatherTimezone *tz;
@@ -327,8 +331,14 @@ parse_metar_stations (const char *contents)
         }
 
         if (g_hash_table_lookup (stations_ht, station)) {
-            if (g_str_equal (station, "VOGO") ||
-                g_str_equal (station, "KHQG")) {
+            const char * const known_duplicates[] = {
+                "VOGO",
+                "KHQG",
+                "KOEL",
+                "KTQK",
+                NULL
+            };
+            if (g_strv_contains (known_duplicates, station)) {
                 g_free (station);
                 continue;
             }
@@ -360,7 +370,7 @@ test_metar_weather_station (GWeatherLocation *location,
 
     line = g_hash_table_lookup (stations_ht, code);
     if (!line) {
-        g_print ("Could not find airport for '%s'\n", code);
+        g_print ("Could not find airport for '%s' in " METAR_SOURCES "\n", code);
         g_test_fail ();
     } else {
         char *has_metar;
@@ -370,7 +380,7 @@ test_metar_weather_station (GWeatherLocation *location,
             g_print ("Airport weather station '%s' is obsolete\n", code);
             g_test_fail ();
         } else if (*has_metar == ' ') {
-            g_print ("Could not find weather station for '%s'\n", code);
+            g_print ("Could not find weather station for '%s' in " METAR_SOURCES "\n", code);
             g_test_fail ();
         }
         g_free (has_metar);
